@@ -48,8 +48,8 @@ class ListInstances(ComputingCommand):
 			map(util.print_instance, instances)
 
 	def _print_short(self, instances):
-		for instance in instances:
-			print "%s  %s %s" % (instance.hostname, instance.uuid, "Running" if instance.running else "Not running")
+		for instance in sorted(instances, key = lambda x: x.hostname):
+			print "%s (%s) %s" % (instance.hostname, instance.uuid, "Running" if instance.running else "Not running")
 
 
 class CreateInstance(ComputingCommand):
@@ -57,11 +57,13 @@ class CreateInstance(ComputingCommand):
 	def add_parser(cls, parent, subparser):
 		p = subparser.add_parser("create-instance", description="Create a new instance.", parents=[parent])
 		p.add_argument("image_uuid", help="UUID of a VPS Image that should be used.")
-		p.add_argument("size", help='Instance size (in units). Allowed values: 0.25, 0.5, 1 - 15, "cpuhog", "cpuhog4".')
+		p.add_argument("size", help='Instance size (in units). Allowed values: 0.25, 0.5, 1 - 15, "cpuhog", "cpuhog4", "1s", "2s", "4s".')
 		p.add_argument("hostname", help="Hostname set at installation time.")
 		p.add_argument("-n", dest="networks", metavar="NETWORK_NAME", action="append",
 			help="Attach these networks to the new instance. Use the list-networks command to list available networks.")
 		p.add_argument("-b", dest="batch_mode", action="store_true", help="Batch mode. Don't confirm the operation.")
+		p.add_argument("-d", dest="disk_size_mb", action="store", type=int,
+			help="For standard instances must set disk size in MB.")
 
 		return "create-instance"
 
@@ -91,6 +93,13 @@ class CreateInstance(ComputingCommand):
 
 		size = self._parse_instance_size(self.args.size)
 
+		# For standard instances - must be set disk_size param
+		disk_size_mb = None
+		if size.endswith("s"):
+			if not self.args.disk_size_mb:
+				raise CommandError("Disk size not set, see -d param.")
+			disk_size_mb = self.args.disk_size_mb
+
 		if not self.args.batch_mode:
 			self.yesno(
 				"Creating new instance with these parameters:\n"
@@ -98,18 +107,18 @@ class CreateInstance(ComputingCommand):
 				"Is this OK?" % (self.args.image_uuid, size, self.args.hostname,
 					", ".join(self.args.networks)))
 
-		response = self.conn.create_instance(self.args.hostname, size, self.args.image_uuid, networks)
+		response = self.conn.create_instance(self.args.hostname, size, self.args.image_uuid, networks, disk_size_mb=disk_size_mb)
 
 		print "Instance", self.args.hostname, "is now being installed."
 
 	def _parse_instance_size(self, sz):
 		"""
 		Parse instance size passed as string and validate it.
-		Valid values are: 0.25, 0.5, integers 1-15, "cpuhog", "cpuhog4"
+		Valid values are: 0.25, 0.5, integers 1-15, "cpuhog", "cpuhog4", "1s", "2s", "4s".
 		Raise CommandError if `sz` is not a valid size.
 		"""
 
-		if sz in ("cpuhog", "cpuhog4"):
+		if sz in ("cpuhog", "cpuhog4", "1s", "2s", "4s"):
 			return sz
 
 		try:
@@ -127,7 +136,7 @@ class CreateInstance(ComputingCommand):
 		if sz is None:
 			raise CommandError('Size must be 0.25, 0.5, integral value 1-15 or "cpuhog".')
 
-		return sz
+		return str(sz)
 
 
 class InstanceCommand(ComputingCommand):
@@ -137,17 +146,41 @@ class InstanceCommand(ComputingCommand):
 
 	@classmethod
 	def add_common_arguments(cls, parser):
-		parser.add_argument("-n", dest="hostname", help="Instance hostname. Use -u if it is not unique.")
-		parser.add_argument("-u", dest="uuid", help="Instance UUID, can be specified instead of name.")
+		group = parser.add_mutually_exclusive_group()
+		group.add_argument("instance", nargs='?', default='',
+				help="Instance hostname prefix, or instance UUID prefix.")
+		group.add_argument("-n", dest="hostname",
+				help="Instance full hostname. Use -u or `instance' argument if the hostname is not unique.")
+		group.add_argument("-u", dest="uuid",
+				help="Instance full UUID. Can be specified instead of name (-n) or `instance' argument.")
 
 	def _instance_from_args(self, actions=False, vpsimage=False, cost=False):
 		if self.args.hostname and self.args.uuid:
 			raise CommandError("Both hostname and UUID can't be specified. Decide on one!")
-		if not self.args.hostname and not self.args.uuid:
-			raise CommandError("Either hostname or UUID must be provided.")
+		if not self.args.hostname and not self.args.uuid and not self.args.instance:
+			raise CommandError("Either `instance' argument, hostname (-n) or UUID (-u) must be provided.")
 
 		try:
-			if self.args.hostname:
+			# select by hostname/uuid prefix
+			if self.args.instance:
+				instances = []
+				for i in Instance.list_all(self.conn):
+					if i.hostname.startswith(self.args.instance):
+						instances.append(i)
+					elif i.uuid.startswith(self.args.instance):
+						instances.append(i)
+				if not instances:
+					raise CommandError("There is no such instance.")
+				if len(instances) > 1:
+					print "Matched more than one instance:"
+					for i in instances:
+						print " - %s (%s)" % (i.hostname, i.uuid)
+					raise CommandError("Select exactly one instance.")
+
+				instance = Instance.get_by_uuid(self.conn, instances[0].uuid,
+						actions, vpsimage, cost)
+			# select by full hostname only:
+			elif self.args.hostname:
 				instances = Instance.get_by_hostname(self.conn, self.args.hostname,
 						actions, vpsimage, cost)
 				if len(instances) > 1:
@@ -156,6 +189,7 @@ class InstanceCommand(ComputingCommand):
 							% (len(instances), self.args.hostname, msg))
 
 				instance = instances[0]
+			# select by full uuid only:
 			else:
 				instance = Instance.get_by_uuid(self.conn, self.args.uuid,
 						actions, vpsimage, cost)
@@ -184,10 +218,12 @@ class StartInstance(InstanceCommand):
 class StopInstance(InstanceCommand):
 	@classmethod
 	def add_parser(cls, parent, subparser):
-		p = subparser.add_parser("stop", description="Stop an instance. Either name or UUID must be specified.", 
+		p = subparser.add_parser("stop",
+				description="Stop an instance. Send ACPI Shutdown signal (default), or stop forcefully (see -f argument)",
 				parents=[parent])
 		InstanceCommand.add_common_arguments(p)
-		p.add_argument("-f", dest="force", action="store_true", help="Stop the instance forcefuly.")
+		p.add_argument("-f", dest="force", action="store_true",
+				help="Stop the instance forcefully. Do not send gently ACPI Shutdown signal, instead cut the power off.")
 
 		return "stop"
 
@@ -220,16 +256,38 @@ class BackupInstance(InstanceCommand):
 		print "Instance %s (%s) is now being backed up" % (instance.hostname, instance.uuid)
 
 
+class DeleteInstance(InstanceCommand):
+	@classmethod
+	def add_parser(cls, parent, subparser):
+		p = subparser.add_parser("delete-instance",
+				description="Permanently remove an instance. Either name or UUID must be specified.", 
+				parents=[parent])
+		InstanceCommand.add_common_arguments(p)
+		return "delete-instance"
+
+	def execute(self):
+		instance = self._instance_from_args()
+		
+		self.conn.delete_instance(instance.uuid)
+		print "Instance %s (%s) is now being removed" % (instance.hostname, instance.uuid)
+
+
 class InstanceInfo(InstanceCommand):
 	@classmethod
 	def add_parser(cls, parent, subparser):
 		p = subparser.add_parser("info", description="Display instance information.", parents=[parent])
+		p.add_argument("-a", "--all", dest="verbose", action="store_true",
+			help="Print all extra information.")
 		InstanceCommand.add_common_arguments(p)
 		return "info"
 
 	def execute(self):
-		instance = self._instance_from_args(actions=True, vpsimage=True, cost=True)
-		util.print_instance(instance)
+		if not self.args.verbose:
+			instance = self._instance_from_args()
+		else:
+			instance = self._instance_from_args(actions=True, vpsimage=True, cost=True)
+			instance.load_block_devices()
+		util.print_instance(instance, self.args.verbose)
 
 
 class AddInterface(InstanceCommand):
